@@ -224,6 +224,16 @@ class DBAPI(DbGeneric):
         if self.transaction == None:
             self.dbapi.rollback()
 
+    def _collation(self, locale):
+        """
+        Get the adjusted collation if there is one, falling back on
+        the locale.collation.
+        """
+        collation = self.dbapi.check_collation(locale)
+        if collation == None:
+            return locale.get_collation()
+        return collation
+
     def transaction_begin(self, transaction):
         """
         Transactions are handled automatically by the db layer.
@@ -231,6 +241,10 @@ class DBAPI(DbGeneric):
         _LOG.debug("    %sDBAPI %s transaction begin for '%s'",
                    "Batch " if transaction.batch else "",
                    hex(id(self)), transaction.get_description())
+        if transaction.batch:
+            # A batch transaction does not store the commits
+            # Aborting the session completely will become impossible.
+            self.abort_possible = False
         self.transaction = transaction
         self.dbapi.begin()
         return transaction
@@ -360,12 +374,9 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             self.dbapi.execute('SELECT handle FROM person '
                                'ORDER BY surname '
-                               'COLLATE "%s"' % locale.get_collation())
+                               'COLLATE "%s"' % self._collation(locale))
         else:
             self.dbapi.execute("SELECT handle FROM person")
         rows = self.dbapi.fetchall()
@@ -382,9 +393,6 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             sql = ('SELECT family.handle ' +
                    'FROM family ' +
                    'LEFT JOIN person AS father ' +
@@ -399,7 +407,7 @@ class DBAPI(DbGeneric):
                    'THEN mother.given_name ' +
                    'ELSE father.given_name ' +
                    'END) ' +
-                   'COLLATE "%s"' % locale.get_collation())
+                   'COLLATE "%s"' % self._collation(locale))
             self.dbapi.execute(sql)
         else:
             self.dbapi.execute("SELECT handle FROM family")
@@ -426,12 +434,9 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             self.dbapi.execute('SELECT handle FROM citation '
                                'ORDER BY page '
-                               'COLLATE "%s"' % locale.get_collation())
+                               'COLLATE "%s"' % self._collation(locale))
         else:
             self.dbapi.execute("SELECT handle FROM citation")
         rows = self.dbapi.fetchall()
@@ -448,12 +453,9 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             self.dbapi.execute('SELECT handle FROM source '
                                'ORDER BY title '
-                               'COLLATE "%s"' % locale.get_collation())
+                               'COLLATE "%s"' % self._collation(locale))
         else:
             self.dbapi.execute("SELECT handle from source")
         rows = self.dbapi.fetchall()
@@ -470,12 +472,9 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             self.dbapi.execute('SELECT handle FROM place '
                                'ORDER BY title '
-                               'COLLATE "%s"' % locale.get_collation())
+                               'COLLATE "%s"' % self._collation(locale))
         else:
             self.dbapi.execute("SELECT handle FROM place")
         rows = self.dbapi.fetchall()
@@ -501,12 +500,9 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             self.dbapi.execute('SELECT handle FROM media '
                                'ORDER BY desc '
-                               'COLLATE "%s"' % locale.get_collation())
+                               'COLLATE "%s"' % self._collation(locale))
         else:
             self.dbapi.execute("SELECT handle FROM media")
         rows = self.dbapi.fetchall()
@@ -532,12 +528,9 @@ class DBAPI(DbGeneric):
         :type locale: A GrampsLocale object.
         """
         if sort_handles:
-            if locale != glocale:
-                self.dbapi.check_collation(locale)
-
             self.dbapi.execute('SELECT handle FROM tag '
                                'ORDER BY name '
-                               'COLLATE "%s"' % locale.get_collation())
+                               'COLLATE "%s"' % self._collation(locale))
         else:
             self.dbapi.execute("SELECT handle FROM tag")
         rows = self.dbapi.fetchall()
